@@ -10,29 +10,32 @@ function(
 ) {
 
    # Pull out the template names for adding to output
-   hits<-detection.obj@detections
+   hits <- detection.obj@detections
 
    # Make sure which.one has template names
-   if(is.numeric(which.one)) which.one<-names(detection.obj@detections)[which.one]
+   if(is.numeric(which.one)) which.one <- names(detection.obj@detections)[which.one]
 
    # Empty list for holding hits
-   results<-list()
+   results <- list()
    for(i in which.one) {
-      dat<-hits[[i]]
+      dat <- hits[[i]]
       if(nrow(dat)>0) {
-         dat$id<-id
-         dat$template<-i
-         # Change order of columns
-         if(is.null(id)) 
-            dat<-dat[,c(ncol(dat),1:(ncol(dat)-1))] else 
-            dat<-dat[,c(ncol(dat)-1:0,1:(ncol(dat)-2))] 
-         results[[i]]<-dat
+         dat$id <- id
+         dat$template <- i
+      } else {
+         if(!is.null(id)) dat$id <- do.call(class(id), list())
+         dat$template <- character()
       }
+      # Change order of columns
+      if(is.null(id)) 
+         dat <- dat[, c(ncol(dat), 1:(ncol(dat)-1))] else 
+         dat <- dat[, c(ncol(dat)-1:0, 1:(ncol(dat)-2))] 
+         results[[i]] <- dat
    }
-
+   
    # Collapse list
-   if(grepl('data',output)) 
-      results<-rbindf(results) else if(!grepl('list',output)) 
+   if(grepl('data', output)) 
+      results <- rbindf(results) else if(!grepl('list', output)) 
       stop('Output option not recognized')
 
    return(results)
